function [ret,x0,str,ts,xts]=identicw(t,x,u,flag);
%IDENTICW	is the M-file description of the SIMULINK system named IDENTICW.
%	The block-diagram can be displayed by typing: IDENTICW.
%
%	SYS=IDENTICW(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes IDENTICW to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling IDENTICW with a FLAG of zero:
%	[SIZES]=IDENTICW([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[12,64,964,642])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '500')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','9',...
		'position',[260,142,315,268])

add_block('built-in/Memory',[sys,'/','Memory1'])
set_param([sys,'/','Memory1'],...
		'position',[635,120,675,150])

add_block('built-in/Memory',[sys,'/','Memory'])
set_param([sys,'/','Memory'],...
		'position',[525,120,565,150])

add_block('built-in/Memory',[sys,'/','Memory2'])
set_param([sys,'/','Memory2'],...
		'position',[615,190,655,220])

add_block('built-in/Memory',[sys,'/','Memory3'])
set_param([sys,'/','Memory3'],...
		'position',[700,190,740,220])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','6',...
		'position',[825,131,855,164])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','ident',...
		'Output Width','5',...
		'position',[695,303,755,337])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'Numerator','[2 -1]',...
		'Denominator','[1 .5 .5]',...
		'position',[500,179,580,231])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'MATLAB Fcn','contid',...
		'Output Width','1',...
		'position',[335,188,395,222])

add_block('built-in/Memory',[sys,'/','Memory4'])
set_param([sys,'/','Memory4'],...
		'position',[420,190,460,220])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'orientation',2,...
		'outputs','5',...
		'position',[620,291,680,349])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'Peak','3.000000',...
		'Peak Range','5000.000000',...
		'Freq','0.062832',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[65,128,110,162])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'orientation',2,...
		'mat-name','erro',...
		'position',[325,382,375,398])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','saida',...
		'position',[855,232,905,248])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[125,15,145,35])
add_line(sys,[570,135;630,135])
add_line(sys,[585,205;610,205])
add_line(sys,[660,205;695,205])
add_line(sys,[680,135;820,135])
add_line(sys,[610,135;610,165;685,165;685,140;820,140])
add_line(sys,[745,205;745,150;820,150])
add_line(sys,[670,205;670,235;770,235;770,155;820,155])
add_line(sys,[585,205;585,245;790,245;790,160;820,160])
add_line(sys,[860,150;930,150;930,320;760,320])
add_line(sys,[690,320;685,320])
add_line(sys,[615,340;615,390;380,390])
add_line(sys,[790,240;850,240])
add_line(sys,[320,205;330,205])
add_line(sys,[615,300;570,300;570,285;245,285;255,160])
add_line(sys,[615,310;525,310;525,295;235,295;235,175;255,175])
add_line(sys,[615,320;565,320;565,395;530,395;530,355;225,355;225,190;255,190])
add_line(sys,[615,330;570,330;570,445;535,445;535,420;215,420;215,205;255,205])
add_line(sys,[595,135;595,110;190,110;190,235;255,235])
add_line(sys,[795,240;795,485;205,485;205,250;255,250])
add_line(sys,[675,235;675,275;810,275;810,500;195,500;195,265;255,265])
add_line(sys,[115,145;255,145])
add_line(sys,[400,205;415,205])
add_line(sys,[465,205;495,205])
add_line(sys,[475,205;475,135;520,135])
add_line(sys,[475,150;415,150;415,130;200,130;200,220;255,220])
add_line(sys,[475,175;705,175;705,145;820,145])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
