function [ret,x0,str,ts,xts]=identiwk(t,x,u,flag);
%IDENTIWK	is the M-file description of the SIMULINK system named IDENTIWK.
%	The block-diagram can be displayed by typing: IDENTIWK.
%
%	SYS=IDENTIWK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes IDENTIWK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling IDENTIWK with a FLAG of zero:
%	[SIZES]=IDENTIWK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,58,628,484])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '500')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Memory',[sys,'/','Memory1'])
set_param([sys,'/','Memory1'],...
		'position',[320,25,360,55])

add_block('built-in/Memory',[sys,'/','Memory'])
set_param([sys,'/','Memory'],...
		'position',[210,25,250,55])

add_block('built-in/Memory',[sys,'/','Memory2'])
set_param([sys,'/','Memory2'],...
		'position',[300,95,340,125])

add_block('built-in/Memory',[sys,'/','Memory3'])
set_param([sys,'/','Memory3'],...
		'position',[385,95,425,125])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','6',...
		'position',[510,36,540,69])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'orientation',2,...
		'MATLAB Fcn','ident',...
		'Output Width','5',...
		'position',[380,208,440,242])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'orientation',2,...
		'outputs','5',...
		'position',[305,204,355,246])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'Numerator','[.5 .5]',...
		'Denominator','[1 .5 .5]',...
		'position',[185,84,265,136])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[110,100,130,120])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator1']])
set_param([sys,'/',['Signal',13,'Generator1']],...
		'Peak','0.500000',...
		'Peak Range','5.000000',...
		'Freq','0.030000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[10,53,55,87])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'orientation',2,...
		'mat-name','a1',...
		'position',[135,182,185,198])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'orientation',2,...
		'mat-name','a2',...
		'position',[135,237,185,253])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'orientation',2,...
		'mat-name','b1',...
		'position',[135,292,185,308])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'orientation',2,...
		'mat-name','b2',...
		'position',[135,342,185,358])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'orientation',2,...
		'mat-name','erro',...
		'position',[210,367,260,383])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','saida',...
		'position',[550,137,600,153])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'Peak','0.000000',...
		'Peak Range','3.000000',...
		'Freq','0.062800',...
		'Freq Range','20.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[10,128,55,162])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[390,340,410,360])
add_line(sys,[255,40;315,40])
add_line(sys,[270,110;295,110])
add_line(sys,[345,110;380,110])
add_line(sys,[365,40;505,40])
add_line(sys,[295,40;295,70;370,70;370,45;505,45])
add_line(sys,[430,110;430,55;505,55])
add_line(sys,[355,110;355,140;455,140;455,60;505,60])
add_line(sys,[270,110;270,150;475,150;475,65;505,65])
add_line(sys,[545,55;615,55;615,225;445,225])
add_line(sys,[375,225;360,225])
add_line(sys,[300,205;255,205;255,190;190,190])
add_line(sys,[300,215;245,215;245,245;190,245])
add_line(sys,[300,225;250,225;250,300;190,300])
add_line(sys,[300,235;255,235;255,350;190,350])
add_line(sys,[300,245;295,245;295,375;265,375])
add_line(sys,[475,145;545,145])
add_line(sys,[135,110;170,110;170,40;205,40])
add_line(sys,[170,80;405,80;405,50;505,50])
add_line(sys,[170,110;180,110])
add_line(sys,[60,145;60,115;105,115])
add_line(sys,[60,70;70,70;70,105;105,105])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
